@@ -1,3 +1,4 @@
+# This file cannot be imported from until Django sets up
 try:
     # Django 1.11
     from django.test.utils import setup_databases, teardown_databases  # noqa
@@ -9,9 +10,3 @@ except ImportError:
         (_DiscoverRunner(verbosity=verbosity,
                          interactive=False)
          .teardown_databases(db_cfg))
-
-try:
-    from django.db.backends.base.base import BaseDatabaseWrapper  # noqa
-except ImportError:
-    # Django 1.7.
-    from django.db.backends import BaseDatabaseWrapper  # noqa
